# Contributors

The full list can be found here: https://github.com/BoboTiG/python-mss/graphs/contributors

That document is mostly useful for users without a GitHub account (sorted alphabetically):

- [bubulle](http://indexerror.net/user/bubulle)
  - Windows: efficiency of MSS.get_pixels()
- [Condé 'Eownis' Titouan](https://titouan.co)
  - MacOS X tester
- [David Becker](https://davide.me)
  - Mac: Take into account extra black pixels added when screen with is not divisible by 16
- [Oros](https://ecirtam.net)
  - GNU/Linux tester
- [yoch](http://indexerror.net/user/yoch)
  - Windows: efficiency of `MSS.get_pixels()`
- Wagoun
  - equipment loan (Macbook Pro)
